'use strict';

// ** Constants
const COMMANDS_JSON = 'commands.json';

// ** Dependencies
const fs = require('fs-extra');
const yargs = require('yargs');
const EventEmitter = require('./events');
const files = require('./files');
const util = require('util');
const Path = require('path');

function Commands(commands) {

    if (!commands)
        commands = files.resolvePath(COMMANDS_JSON);

    if (commands && util.isString(commands))
        commands = fs.existsSync(commands) ?
        files.requireFile(commands) :
        {};

    return commands;
}

const Name = (name) => name
    ? name  // argument value
    : fs.existsSync(files.resolvePath('package.json'))
    ? files.requireFile('package.json').name   // NPM Package
    : Path.parse(files.resolvePath('.')).base // Directory Name

class CLI extends EventEmitter {
    constructor(options = {}) {
        super();

        this.name = Name(options.name);
        this.commands = Commands(options.commands);
    }

    run() {
        const args = yargs.argv;

        const command = args._.shift();
        
        return {command};
    }
}

function createCLI(options) {
    const cli = new CLI(options);
    return cli;
}

// ** Exports
module.exports = createCLI;
module.exports.CLI = CLI;